@@ -6,15 +6,16 @@ use base 'Class::Singleton';
 use Crypt::CBC;
 use Digest::CRC qw(crc8);
 use Carp;
+use Digest::MD5 qw(md5);
 use bytes;
 
 sub _new_instance {
 	my ($class, $key) = @_;
 	my $self = bless({}, $class);
 	confess "No key!" unless $key;
+	my ($iv) = (md5($key) =~ /^(.{8})/);
 	my $c = Crypt::CBC->new(-key => $key, -cipher => 'Blowfish'
-			, -iv => Crypt::CBC->random_bytes(8)
-			, -header => 'randomiv');
+			, -iv => $iv, -header => 'none');
 	confess "No cipher!" unless $c;
 	$self->{_cipher} = $c;
 	return $self;
